pub struct WpAlphaModifierSurfaceV1 { /* private fields */ }Expand description
alpha modifier object for a surface
This interface allows the client to set a factor for the alpha values on a surface, which can be used to offload such operations to the compositor. The default factor is UINT32_MAX.
This object has to be destroyed before the associated wl_surface. Once the wl_surface is destroyed, all request on this object will raise the no_surface error.
This interface has no events.
Implementations
Sourceimpl WpAlphaModifierSurfaceV1
impl WpAlphaModifierSurfaceV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the alpha modifier object
This destroys the object, and is equivalent to set_multiplier with a value of UINT32_MAX, with the same double-buffered semantics as set_multiplier.
Sourcepub fn set_multiplier(&self, factor: u32)
pub fn set_multiplier(&self, factor: u32)
specify the alpha multiplier
Sets the alpha multiplier for the surface. The alpha multiplier is double-buffered state, see wl_surface.commit for details.
This factor is applied in the compositor’s blending space, as an additional step after the processing of per-pixel alpha values for the wl_surface. The exact meaning of the factor is thus undefined, unless the blending space is specified in a different extension.
This multiplier is applied even if the buffer attached to the wl_surface doesn’t have an alpha channel; in that case an alpha value of one is used instead.
Zero means completely transparent, UINT32_MAX means completely opaque.